@@ -1,5 +1,5 @@
-__version__ = "0.1.0"
+__version__ = "0.1.4"
 
+from .polygon_plus import NY as NY
 from .polygon_plus import async_polygon_aggs as async_polygon_aggs
 from .polygon_plus import nyse as nyse
-from .polygon_plus import schedule as schedule
